Predictive Modeling
====================================

Decision Trees
---------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.decision_trees
   :members:
   :undoc-members:
   :show-inheritance:

KMeans
------------------------------------------

.. automodule:: nzpyida.analytics.predictive.kmeans
   :members:
   :undoc-members:
   :show-inheritance:

KNN
---------------------------------------

.. automodule:: nzpyida.analytics.predictive.knn
   :members:
   :undoc-members:
   :show-inheritance:

Linear Regression
------------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.linear_regression
   :members:
   :undoc-members:
   :show-inheritance:

Naive Bayes
------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.naive_bayes
   :members:
   :undoc-members:
   :show-inheritance:

Regression Trees
-----------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.regression_trees
   :members:
   :undoc-members:
   :show-inheritance:

Association Rules
-----------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.association_rules
   :members:
   :undoc-members:
   :show-inheritance:

Bisecting KMeans
-----------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.bisecting_kmeans
   :members:
   :undoc-members:
   :show-inheritance:

Two Step Clustering
-----------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.two_step_clustering
   :members:
   :undoc-members:
   :show-inheritance:

Time Series Forecasting
-----------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.timeseries
   :members:
   :undoc-members:
   :show-inheritance:

Tree Bayesian Networks
-----------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.bayesian_networks
   :members:
   :undoc-members:
   :show-inheritance:

Generalized Linear Models
-----------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.glm
   :members:
   :undoc-members:
   :show-inheritance:

Classification base module
--------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.classification
   :members:
   :undoc-members:
   :show-inheritance:

Regression base module
----------------------------------------------

.. automodule:: nzpyida.analytics.predictive.regression
   :members:
   :undoc-members:
   :show-inheritance:

Predictive Modeling base module
--------------------------------------------------------

.. automodule:: nzpyida.analytics.predictive.predictive_modeling
   :members:
   :undoc-members:
   :show-inheritance:
